;*****************************************************************************
;  EDU RC-5 test for TEB bands. Calculates the SNR and NEdT. Fits the SNR
;  to the Plank radiance of the BCS (using a function with Powell's method
;  or a cubic polynomial with poly_fit) with or without weights of 1/std.
;
;  Input:
;  1) Input file.
;
;  Output:
;  1) SNR[collect,band,HAM,detector,subsample]
;  2) snr_1[band,HAM,detector,subsample,coefficients,fit type,not weighted or weighted]
;  3) snr_2[band,detector,coefficients,fit type,not weighted or weighted]
;  4) snr_fit[collect,band,HAM,detector,subsample,fit type,not weighted or weighted]
;  5) NEdL[collect,b,HAM,detector,subsample,fit type,not weighted or weighted]
;  6) NEdT[collect,band,HAM,detector,subsample,fit type,not weighted or weighted]
;  7) NEdL_typ[band,HAM,detector,subsample,fit type,not weighted or weighted]
;  8) NEdT_typ[band,HAM,detector,subsample,fit type,not weighted or weighted]
;
;  v1.0 - 04/3/2008 - Jeff McIntire
;*****************************************************************************

;*****************************************************************************
;  Function for powell's method.
;*****************************************************************************

FUNCTION powfunc, xx

COMMON X1,b
COMMON X2,id
COMMON X3,ih
COMMON X4,is
COMMON X5,ncollects
COMMON X6,SNR
COMMON X7,rad_BCS
COMMON X8,lcol
COMMON X9,hcol
COMMON X10,w

X=fltarr(ncollects)

Z=0
FOR col=lcol, hcol-1 DO BEGIN
	IF (xx[0]+xx[1]*rad_BCS[col,b,ih,id,is]+xx[2]*rad_BCS[col,b,ih,id,is]^2) LT 0 THEN RETURN,1000000
	X[col]=rad_BCS[col,b,ih,id,is]-SNR[col,b,ih,id,is] $
		*sqrt(xx[0]+xx[1]*rad_BCS[col,b,ih,id,is]+xx[2]*rad_BCS[col,b,ih,id,is]^2)

	Z=Z+w[col]*X[col]^2/total(w)
ENDFOR

RETURN,Z

END

;*****************************************************************************
;  Main program.
;*****************************************************************************

PRO RC5_SNR_NEdT, infile

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

infname1=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
restore,infname1
restore,infname2
restore,infname3

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

outfile=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'

COMMON X1,b
COMMON X2,id
COMMON X3,ih
COMMON X4,is
COMMON X5,ncollects
COMMON X6,SNR
COMMON X7,rad_BCS
COMMON X8,lcol
COMMON X9,hcol
COMMON X10,w

;*****************************************************************************
;  Calculate the SNR.
;*****************************************************************************

SNR=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets)

SNR[*,*,*,*,*]=dn[*,*,*,*,*,0]/std[*,*,*,*,*,0]

;*****************************************************************************
;  Powell's method and ploy_fit (cubic) for fitting SNR to BCS radiance.
;*****************************************************************************

c=dblarr(ncollects)
d=dblarr(ncollects)
w=dblarr(ncollects)

snr_1=dblarr(nbands_TEB,nham,maxdet,maxsubsets,4,2,2)
snr_fit=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,2)
snr_2=dblarr(nbands_TEB,maxdet,4,2,2)

FOR ifit=0, 1 DO BEGIN
	FOR b=0, nbands_TEB-1 DO BEGIN
		lcol=0
		hcol=ncollects
		FOR col=0, ncollects-1 DO BEGIN
			IF rad_p1[b,col,0] LT L_min_TEB[b] THEN lcol=lcol+1
			IF rad_p1[b,col,0] GT L_max_TEB[b] THEN hcol=hcol-1
		ENDFOR
		FOR is=0, subsets_TEB[b]-1 DO BEGIN
			FOR ih=0, nham-1 DO BEGIN
				FOR id=0, detectors_TEB[b]-1 DO BEGIN
					IF ifit EQ 0 THEN w[*]=1.0
					IF ifit EQ 1 THEN w[*]=1/std[*,b,ih,id,is,2]^2

					P=[.000001,.000001,.000001]
					ftol=0.00000001
					xi=TRANSPOSE([[0.0,1.0,0.0],[0.0,0.0,1.0],[1.0,0.0,0.0]])

					powell,P,xi,ftol,fmin,'powfunc',/DOUBLE
					snr_1[b,ih,id,is,0:2,0,ifit]=P[0:2]

					c[*]=rad_BCS[*,b,ih,id,is]
					d[*]=SNR[*,b,ih,id,is]

					result=poly_fit(c,d,3)
					snr_1[b,ih,id,is,*,1,ifit]=result[*]

					print,ifit,b,id,ih,is,P[0],P[1],P[2],fmin,result[0],result[1],result[2]

					snr_fit[*,b,ih,id,is,0,ifit]=(SNR[*,b,ih,id,is]-rad_BCS[*,b,ih,id,is] $
						/sqrt(P[0]+P[1]*rad_BCS[*,b,ih,id,is]+P[2]*rad_BCS[*,b,ih,id,is]^2)) $
						/SNR[*,b,ih,id,is]
					snr_fit[*,b,ih,id,is,1,ifit]=(SNR[*,b,ih,id,is]-result[0] $
						-result[1]*rad_BCS[*,b,ih,id,is]-result[2]*rad_BCS[*,b,ih,id,is]^2 $
						-result[3]*rad_BCS[*,b,ih,id,is]^3)/SNR[*,b,ih,id,is]
				ENDFOR
			ENDFOR
		ENDFOR
		IF band_type_TEB[b] EQ 1 THEN snr_2[b,*,*,*,ifit]=(snr_1[b,0,*,0,*,*,ifit]+snr_1[b,0,*,1,*,*,ifit] $
			+snr_1[b,1,*,0,*,*,ifit]+snr_1[b,1,*,1,*,*,ifit])/4
		IF band_type_TEB[b] EQ 0 THEN snr_2[b,*,*,*,ifit]=(snr_1[b,0,*,0,*,*,ifit]+snr_1[b,1,*,0,*,*,ifit])/2
	ENDFOR
ENDFOR

;*****************************************************************************
;  Calulate the NEdL and NEdT.
;*****************************************************************************

NEdL=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,2)
NEdT=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,2)
NEdL_typ=dblarr(nbands_TEB,nham,maxdet,maxsubsets,2,2)
NEdT_typ=dblarr(nbands_TEB,nham,maxdet,maxsubsets,2,2)

FOR ifit1=0, 1 DO BEGIN
	FOR b=0, nbands_TEB-1 DO BEGIN
		FOR col=0, ncollects-1 DO BEGIN
			FOR ifit2=0, 1 DO BEGIN
				NEdL[col,b,*,*,*,ifit2,ifit1]=rad_BCS[col,b,*,*,*]/SNR[col,b,*,*,*]
				NEdT[col,b,*,*,*,ifit2,ifit1]=NEdL[col,b,*,*,*,ifit2,ifit1] $
					/Planck_deriv(T_bcs[col],lambda_TEB[b])
			ENDFOR
		ENDFOR
		NEdL_typ[b,*,*,*,0,ifit1]=sqrt(snr_1[b,*,*,*,0,0,ifit1] $
			+snr_1[b,*,*,*,1,0,ifit1]*L_typ_TEB[b,0]+snr_1[b,*,*,*,2,0,ifit1]*L_typ_TEB[b,0]^2)
		NEdT_typ[b,*,*,*,0,ifit1]=NEdL_typ[b,*,*,*,0,ifit1]/Planck_deriv(T_typ_TEB[b],lambda_TEB[b])
		NEdL_typ[b,*,*,*,1,ifit1]=L_typ_TEB[b,0]/(snr_1[b,*,*,*,0,1,ifit1] $
			+snr_1[b,*,*,*,1,1,ifit1]*L_typ_TEB[b,0]+snr_1[b,*,*,*,2,1,ifit1]*L_typ_TEB[b,0]^2 $
			+snr_1[b,*,*,*,3,1,ifit1]*L_typ_TEB[b,0]^3)
		NEdT_typ[b,*,*,*,1,ifit1]=NEdL_typ[b,*,*,*,1,ifit1]/Planck_deriv(T_typ_TEB[b],lambda_TEB[b])

print,ifit,b,NEdL[0,b,0,0,0,0,ifit1],NEdL[0,b,0,7,0,0,ifit1],NEdL[0,b,0,15,0,0,ifit1],rad_BCS[0,b,0,0,0],rad_BCS[0,b,0,7,0],rad_BCS[0,b,0,15,0],SNR[0,b,0,0,0],SNR[0,b,0,7,0],SNR[0,b,0,15,0],Planck_deriv(T_typ_TEB[b],lambda_TEB[b])

	ENDFOR
ENDFOR

save,/compress,SNR,snr_1,snr_2,snr_fit,NEdL,NEdT,NEdL_typ,NEdT_typ,filename=outfile

END
