;*****************************************************************************
;  EDU RC-5 test for TEB bands. Calculates the The effective EV source radiance
;  and compares to specifications.
;
;  Input:
;  1) RVS data.
;  2) Band dependent reflectence of the RTA (p).
;  3) Radiances of HAM, RTA, and SVS.
;  4) Fitting coefficients and gain correction.
;
;  Output:
;  1) rad_BCS_ret[collect,band,HAM,detector,subsample,ifit,cor]
;  2) ARD[collect,band,HAM,detector,subsample,ifit,cor]
;  3) RCU[collect,band,HAM,subsample,ifit,cor] 
;  
;  v1.0 - 04/14/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_eff_rad, infile

;*****************************************************************************
;  Read in input file and sav TEB file.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

infname1=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
infname4=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname5=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
restore,infname1
restore,infname2
restore,infname3
restore,infname4
restore,infname5

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

outfile=outpath+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]
p=[0.9235,0.9268,0.9222,0.9282,0.8993,0.9219,0.9285,0.9285]

rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,3)
rad_OBC_ret=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,3)
ARD=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,3)
ARD_obc=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,3)
mean_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
mean_rad_OBC_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
max_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
max_rad_OBC_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
min_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
min_rad_OBC_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
std_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
std_rad_OBC_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
mean_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
mean_ARD_obc=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
max_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
max_ARD_obc=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
std_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
std_ARD_obc=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
RRU=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)
RRU_obc=dblarr(ncollects,nbands_TEB,nham,maxsubsets,2,3)

FOR ifit=0, 2 DO BEGIN
	FOR cor=0, 1 DO BEGIN
		FOR col=0, ncollects-1 DO BEGIN
			FOR b=0, nbands_TEB-1 DO BEGIN
				FOR is=0, subsets_TEB[b]-1 DO BEGIN
					FOR ih=0, nham-1 DO BEGIN
						FOR id=0, detectors_TEB[b]-1 DO BEGIN
							IF ifit LE 1 THEN rad_BCS_ret[col,b,ih,id,is,cor,ifit] $
								=(rg_1[b,ih,id,is,0,cor,ifit] $
								+rg_1[b,ih,id,is,1,cor,ifit]*dn[col,b,ih,id,is,0] $
								+rg_1[b,ih,id,is,2,cor,ifit]*dn[col,b,ih,id,is,0]^2) $
								/(gc[col,b,ih,id,is,ifit]*rvs[b,is,id,ih,0]*p[b]) $
								+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[b,col,1] $
								+(rvs[b,is,id,ih,0]-rvs[b,is,id,ih,1])/(rvs[b,is,id,ih,0]*p[b]) $
								*(rad_p2[b,ih,col,0]-(1-p[b])*rad_p2[b,ih,col,1])
							IF ifit GT 1 THEN rad_BCS_ret[col,b,ih,id,is,cor,ifit] $
								=(rg_1[b,ih,id,is,0,cor,ifit] $
								+rg_1[b,ih,id,is,1,cor,ifit]*dn[col,b,ih,id,is,0] $
								+rg_1[b,ih,id,is,2,cor,ifit]*dn[col,b,ih,id,is,0]^2 $
								+rg_1[b,ih,id,is,3,cor,ifit]*dn[col,b,ih,id,is,0]^3) $
								/(gc[col,b,ih,id,is,ifit]*rvs[b,is,id,ih,0]*p[b]) $
								+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[b,col,1] $
								+(rvs[b,is,id,ih,0]-rvs[b,is,id,ih,1])/(rvs[b,is,id,ih,0]*p[b]) $
								*(rad_p2[b,ih,col,0]-(1-p[b])*rad_p2[b,ih,col,1])
							IF ifit LE 1 THEN rad_OBC_ret[col,b,ih,id,is,cor,ifit] $
								=rad_BCS[col,b,ih,id,is]*(rg_1[b,ih,id,is,0,cor,ifit] $
								+rg_1[b,ih,id,is,1,cor,ifit]*dn_obc[col,b,ih,id,is,0] $
								+rg_1[b,ih,id,is,2,cor,ifit]*dn_obc[col,b,ih,id,is,0]^2) $
								/(rvs[b,is,id,ih,2]*p[b]*(rg_1[b,ih,id,is,0,cor,ifit] $
								+rg_1[b,ih,id,is,1,cor,ifit]*dn[col,b,ih,id,is,0] $
								+rg_1[b,ih,id,is,2,cor,ifit]*dn[col,b,ih,id,is,0]^2)) $
								+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,2])*rad_p1[b,col,1] $
								+(rvs[b,is,id,ih,2]-rvs[b,is,id,ih,1])/(rvs[b,is,id,ih,2]*p[b]) $
								*(rad_p2[b,ih,col,0]-(1-p[b])*rad_p2[b,ih,col,1])
							IF ifit GT 1 THEN rad_OBC_ret[col,b,ih,id,is,cor,ifit] $
								=rad_BCS[col,b,ih,id,is]*(rg_1[b,ih,id,is,0,cor,ifit] $
								+rg_1[b,ih,id,is,1,cor,ifit]*dn_obc[col,b,ih,id,is,0] $
								+rg_1[b,ih,id,is,2,cor,ifit]*dn_obc[col,b,ih,id,is,0]^2 $
								+rg_1[b,ih,id,is,3,cor,ifit]*dn_obc[col,b,ih,id,is,0]^3) $
								/(rvs[b,is,id,ih,0]*p[b]*(rg_1[b,ih,id,is,0,cor,ifit] $
								+rg_1[b,ih,id,is,1,cor,ifit]*dn[col,b,ih,id,is,0] $
								+rg_1[b,ih,id,is,2,cor,ifit]*dn[col,b,ih,id,is,0]^2 $
								+rg_1[b,ih,id,is,3,cor,ifit]*dn[col,b,ih,id,is,0]^3)) $
								+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[b,col,1] $
								+(rvs[b,is,id,ih,0]-rvs[b,is,id,ih,1])/(rvs[b,is,id,ih,0]*p[b]) $
								*(rad_p2[b,ih,col,0]-(1-p[b])*rad_p2[b,ih,col,1])

							ARD[col,b,ih,id,is,cor,ifit] $
								=100*(rad_BCS_ret[col,b,ih,id,is,cor,ifit]-rad_p1[b,col,0]) $
								/rad_p1[b,col,0]
							ARD_obc[col,b,ih,id,is,cor,ifit] $
								=100*(rad_OBC_ret[col,b,ih,id,is,cor,ifit]-rad_p2[b,ih,col,4]) $
								/rad_p2[b,ih,col,4]
						ENDFOR

;IF ARD[col,b,ih,0,is,cor,ifit] GT 10 AND b NE 4 THEN print,col,b,is,ih,ARD[col,b,ih,0,is,cor,ifit],rad_BCS_ret[col,b,ih,0,is,cor,ifit]-rad_p1[b,col,0],(rad_BCS_ret[col,b,ih,0,is,cor,ifit]-rad_p1[b,col,0])/rad_p1[b,col,0]

						mean_rad_BCS_ret[col,b,ih,is,cor,ifit] $
							=sig_mean(rad_BCS_ret[col,b,ih,*,is,cor,ifit],3,1)
						mean_rad_OBC_ret[col,b,ih,is,cor,ifit] $
							=sig_mean(rad_OBC_ret[col,b,ih,*,is,cor,ifit],3,1)
						max_rad_BCS_ret[col,b,ih,is,cor,ifit] $
							=max(rad_BCS_ret[col,b,ih,0:detectors_TEB[b]-1,is,cor,ifit],min=min_rad)
						min_rad_BCS_ret[col,b,ih,is,cor,ifit]=min_rad
						max_rad_OBC_ret[col,b,ih,is,cor,ifit] $
							=max(rad_OBC_ret[col,b,ih,0:detectors_TEB[b]-1,is,cor,ifit],min=min_rad)
						min_rad_OBC_ret[col,b,ih,is,cor,ifit]=min_rad
						std_rad_BCS_ret[col,b,ih,is,cor,ifit] $
							=sig_mean(rad_BCS_ret[col,b,ih,*,is,cor,ifit],3,2)
						std_rad_OBC_ret[col,b,ih,is,cor,ifit] $
							=sig_mean(rad_OBC_ret[col,b,ih,*,is,cor,ifit],3,2)
						mean_ARD[col,b,ih,is,cor,ifit]=sig_mean(ARD[col,b,ih,*,is,cor,ifit],3,1)
						mean_ARD_obc[col,b,ih,is,cor,ifit]=sig_mean(ARD_obc[col,b,ih,*,is,cor,ifit],3,1)
						max_ARD[col,b,ih,is,cor,ifit] $
							=max(abs(ARD[col,b,ih,0:detectors_TEB[b]-1,is,cor,ifit]))
						max_ARD_obc[col,b,ih,is,cor,ifit] $
							=max(abs(ARD_obc[col,b,ih,0:detectors_TEB[b]-1,is,cor,ifit]))
						std_ARD[col,b,ih,is,cor,ifit]=sig_mean(ARD[col,b,ih,*,is,cor,ifit],3,2)
						std_ARD_obc[col,b,ih,is,cor,ifit]=sig_mean(ARD_obc[col,b,ih,*,is,cor,ifit],3,2)
;print,col,b,is,ih,mean_rad_BCS_ret[col,b,ih,is,cor,ifit],max_rad_BCS_ret[col,b,ih,is,cor,ifit],min_rad_BCS_ret[col,b,ih,is,cor,ifit],std_rad_BCS_ret[col,b,ih,is,cor,ifit],mean_ARD[col,b,ih,is,cor,ifit],max_ARD[col,b,ih,is,cor,ifit],std_ARD[col,b,ih,is,cor,ifit]
						IF b NE 4 THEN RRU[col,b,ih,is,cor,ifit] $
							=max(abs(rad_BCS_ret[col,b,ih,0:detectors_TEB[b]-1,is,cor,ifit] $
							-sig_mean(rad_BCS_ret[col,b,ih,*,is,cor,ifit],3,1))) $
							/(NEdT_spec[b,0]*Planck_deriv(T_typ_TEB[b],lambda_TEB[b]))
						IF b NE 4 THEN RRU_obc[col,b,ih,is,cor,ifit] $
							=max(abs(rad_OBC_ret[col,b,ih,0:detectors_TEB[b]-1,is,cor,ifit] $
							-sig_mean(rad_OBC_ret[col,b,ih,*,is,cor,ifit],3,1))) $
							/(NEdT_spec[b,0]*Planck_deriv(T_typ_TEB[b],lambda_TEB[b]))
						IF b EQ 4 THEN RRU[col,b,ih,is,cor,ifit] $
							=max(abs(rad_BCS_ret[col,b,ih,1:detectors_TEB[b]-1,is,cor,ifit] $
							-sig_mean(rad_BCS_ret[col,b,ih,1:detectors_TEB[b]-1,is,cor,ifit],3,1))) $
							/(NEdT_spec[b,0]*Planck_deriv(T_typ_TEB[b],lambda_TEB[b]))
						IF b EQ 4 THEN RRU_obc[col,b,ih,is,cor,ifit] $
							=max(abs(rad_OBC_ret[col,b,ih,1:detectors_TEB[b]-1,is,cor,ifit] $
							-sig_mean(rad_OBC_ret[col,b,ih,1:detectors_TEB[b]-1,is,cor,ifit],3,1))) $
							/(NEdT_spec[b,0]*Planck_deriv(T_typ_TEB[b],lambda_TEB[b]))
print,col,b,is,ih,RRU[col,b,ih,is,cor,ifit]
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

save,/compress,rad_BCS_ret,rad_OBC_ret,ARD,ARD_obc,RRU,RRU_obc,filename=outfile

END
