;*****************************************************************************
;  RC5 EDU graphs the delta BCS radiance versus dn, SNR vs delta BCS radiance
;  and NEdT vs delta BCS radiance.
;
;  Output:
;  1) postscript file containing graphs.
;  
;  v1.0 - 04/02/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_view, infile

close,/all

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,2,1]

infname=strarr(4)
infname[0]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname[1]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname[2]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname[3]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
check=FILE_SEARCH(infname[0])
IF check EQ '' THEN BEGIN
	print,'No file is found.',infname[0]
	goto,skip_loop
ENDIF
FOR i=0, 3 DO BEGIN
	print,'Processing file:',infname[i]
	restore,infname[i]
ENDFOR

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)

;*****************************************************************************
;  Plot delta BCS radiance versus dn with fits (quadratic ameoba, quadratic pol_fit,
;  and cubic poly_fit).
;*****************************************************************************

title=strarr(4)

!p.multi=[0,2,3]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': dn vs dL_BCS'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': dn vs dL_BCS'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
			ENDIF

			ymax=max(L_max_TEB[b,0])
			xmax1=max(dn[*,b,ih,*,is,0])

			FOR j=0, 2 DO BEGIN
				plot,dn[*,b,ih,1,is,0],rad_BCS[*,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax1], $
					ytit='dL_BCS',xtit='dn',title=title[j],charsize=1.2,charthick=5,/nodata

				FOR id=0, detectors_TEB[b]-1 DO BEGIN
					oplot,dn[*,b,ih,id,is,0],rad_BCS[*,b,ih,id,is],symsize=1,color=lcol[id],psym=symbol[id]
					IF j LE 1 THEN oplot,rg_1[b,ih,id,is,0,0,j]+rg_1[b,ih,id,is,1,0,j]*D $
						+rg_1[b,ih,id,is,2,0,j]*D^2,color=lcol[id]
					IF j GT 1 THEN oplot,rg_1[b,ih,id,is,0,0,j]+rg_1[b,ih,id,is,1,0,j]*D $
						+rg_1[b,ih,id,is,2,0,j]*D^2+rg_1[b,ih,id,is,3,0,j]*D^3,color=lcol[id]
				ENDFOR
				oplot,[-100,10000],[L_max_TEB[b,0],L_max_TEB[b,0]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
				oplot,[-100,10000],[L_typ_TEB[b,0],L_typ_TEB[b,0]],symsize=1,color=lcol[2],linestyle=2,thick=1.5
				oplot,[-100,10000],[L_min_TEB[b,0],L_min_TEB[b,0]],symsize=1,color=lcol[3],linestyle=2,thick=1.5

				xmax2=max(L_max_TEB[b,0])

				plot,rad_BCS[*,b,ih,0,is],dL_fit[*,b,ih,0,is,0,j],xtit='dL_BCS',ytit='Fitting Residual', $
					yrange=[-0.3,0.3],xrange=[0,xmax2],title=title[j],charsize=1.2,charthick=5,/nodata

				FOR id=0, detectors_TEB[b]-1 DO BEGIN
					oplot,rad_BCS[*,b,ih,id,is],dL_fit[*,b,ih,id,is,0,j],symsize=1,color=lcol[id], $
						psym=symbol[id]
					oplot,rad_BCS[*,b,ih,id,is],dL_fit[*,b,ih,id,is,0,j],color=lcol[id]
				ENDFOR
				oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=1.5
				oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=1.5
				oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=1.5
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol

			IF band_type_TEB[b] EQ 0 THEN BEGIN
			title1=band_name_TEB[b]+': dn vs dL_BCS (with GC)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba with GC)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit with GC)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit with GC)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
			title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': dn vs dL_BCS (with GC)'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba with GC)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit with GC)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit with GC)'
			ENDIF

			FOR j=0, 2 DO BEGIN
				plot,dn[*,b,ih,1,is,0],rad_BCS[*,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax1], $
					xtit='dn',ytit='dL_BCS (with GC)',title=title[j],charsize=1.2,charthick=5,/nodata

				FOR id=0, detectors_TEB[b]-1 DO BEGIN
					oplot,dn[*,b,ih,id,is,0],rad_BCS[*,b,ih,id,is]*gc[*,b,ih,id,is,j], $
						symsize=1,color=lcol[id],psym=symbol[id]
					IF j LE 1 THEN oplot,rg_1[b,ih,id,is,0,1,j]+rg_1[b,ih,id,is,1,1,j]*D $
						+rg_1[b,ih,id,is,2,1,j]*D^2,color=lcol[id]
					IF j GT 1 THEN oplot,rg_1[b,ih,id,is,0,1,j]+rg_1[b,ih,id,is,1,1,j]*D $
						+rg_1[b,ih,id,is,2,1,j]*D^2+rg_1[b,ih,id,is,3,1,j]*D^3,color=lcol[id]
				ENDFOR
				oplot,[-100,10000],[L_max_TEB[b,0],L_max_TEB[b,0]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
				oplot,[-100,10000],[L_typ_TEB[b,0],L_typ_TEB[b,0]],symsize=1,color=lcol[2],linestyle=2,thick=1.5
				oplot,[-100,10000],[L_min_TEB[b,0],L_min_TEB[b,0]],symsize=1,color=lcol[3],linestyle=2,thick=1.5

				plot,rad_BCS[*,b,ih,0,is],dL_fit[*,b,ih,0,is,1,0],xtit='dL_BCS', $
					ytit='Fitting Residual (with GC)',yrange=[-0.3,0.3],xrange=[0,xmax2], $
					title=title1,charsize=1.2,charthick=5,/nodata
	
				FOR id=0, detectors_TEB[b]-1 DO BEGIN
					oplot,rad_BCS[*,b,ih,id,is],dL_fit[*,b,ih,id,is,1,j],symsize=1,color=lcol[id], $
						psym=symbol[id]
					oplot,rad_BCS[*,b,ih,id,is],dL_fit[*,b,ih,id,is,1,j],color=lcol[id]
				ENDFOR
				oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=1.5
				oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=1.5
				oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=1.5
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Plot SNR versus delta BCS radiance with (cubic polynomial) fits and residuals.
;*****************************************************************************

!p.multi=[0,2,2]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': SNR vs dL_BCS'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (function powell)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted function powell)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted cubic poly_fit)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': SNR vs dL_BCS'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (function powell)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted function powell)'
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted cubic poly_fit)'
			ENDIF

			ymax=max(SNR[*,b,ih,*,is])
			xmax=max(L_max_TEB[b,0])

			j=0
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,rad_BCS[*,b,ih,0,is],SNR[*,b,ih,1,is],yrange=[0,ymax],xrange=[0,xmax], $
						xtit='dL_BCS',ytit='SNR',title=title[j],charsize=1.2,charthick=5,/nodata

					F[*]=0.1*E[*]
					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						oplot,rad_BCS[*,b,ih,id,is],SNR[*,b,ih,id,is],symsize=1,color=lcol[id], $
							psym=symbol[id]
						IF ifit2 EQ 0 THEN oplot,F[*],F[*]/sqrt(snr_1[b,ih,id,is,0,ifit2,ifit] $
							+snr_1[b,ih,id,is,1,ifit2,ifit]*F[*] $
							+snr_1[b,ih,id,is,2,ifit2,ifit]*F[*]^2),color=lcol[id]
						IF ifit2 EQ 1 THEN oplot,F[*],snr_1[b,ih,id,is,0,ifit2,ifit] $
							+snr_1[b,ih,id,is,1,ifit2,ifit]*F[*] $
							+snr_1[b,ih,id,is,2,ifit2,ifit]*F[*]^2 $
							+snr_1[b,ih,id,is,3,ifit2,ifit]*F[*]^3,color=lcol[id]
					ENDFOR
					oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,10000],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,10000],symsize=1,color=lcol[2], $
						linestyle=2,thick=1.5
					oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,10000],symsize=1,color=lcol[3], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol

			; Start the fitting residual plots.
			j=0
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,rad_BCS[*,b,ih,0,is],snr_fit[*,b,ih,0,is,1,ifit],xtit='rad_BCS', $
						ytit='SNR Fitting Residual',xrange=[0,xmax],yrange=[-0.5,0.5],title=title[j], $
						charsize=1.2,charthick=5,/nodata

					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						oplot,rad_BCS[*,b,ih,id,is],snr_fit[*,b,ih,id,is,ifit2,ifit],symsize=1, $
							color=lcol[id],psym=symbol[id]
						oplot,rad_BCS[*,b,ih,id,is],snr_fit[*,b,ih,id,is,ifit2,ifit],color=lcol[id]
					ENDFOR
					oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,10000],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,10000],symsize=1,color=lcol[2], $
						linestyle=2,thick=1.5
					oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,10000],symsize=1,color=lcol[3], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR

			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  NEdT from polynomial fit.
;*****************************************************************************

!p.multi=[0,2,2]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': NEdT vs dL_BCS'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (function powell)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted function powell)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted cubic poly_fit)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': NEdT vs dL_BCS'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (function powell)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted function powell)'
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted cubic poly_fit)'
			ENDIF

			xmax=max(L_max_TEB[b,0])

			j=0
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,rad_BCS[*,b,ih,0,is],NEdT[*,b,ih,0,is,1,ifit],xtit='dL_BCS',ytit='NEdT', $
						yrange=[-0.5,0.5],xrange=[0,xmax],title=title[j],charsize=1.2,charthick=5,/nodata

					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						oplot,rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,ifit2,ifit],symsize=1, $
							color=lcol[id],psym=symbol[id]
						oplot,rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,ifit2,ifit],color=lcol[id]
					ENDFOR
					oplot,[L_max_TEB[b,0],L_max_TEB[b,0]],[-100,100],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					oplot,[L_typ_TEB[b,0],L_typ_TEB[b,0]],[-100,100],symsize=1,color=lcol[2], $
						linestyle=2,thick=1.5
					oplot,[L_min_TEB[b,0],L_min_TEB[b,0]],[-100,100],symsize=1,color=lcol[3], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
			IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
		ENDFOR
	ENDFOR
ENDFOR

skip_loop:

END
