;*****************************************************************************
;  RC5 EDU graphs of the specifications.
;  
;  Output:
;  1) postscript file containing graphs.
;
;  v1.0 - 04/18/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_view_req, infile

close,/all

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.req.ps'
device,/landscape,filename=outfname,/color

infname=strarr(6)
infname[0]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname[1]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname[2]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname[3]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
infname[4]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'
infname[5]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
check=FILE_SEARCH(infname[0])
IF check EQ '' THEN BEGIN
	print,'No file is found.',infname[0]
	goto,skip_loop
ENDIF
FOR i=0, 5 DO BEGIN
	print,'Processing file:',infname[i]
	restore,infname[i]
ENDFOR

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)

;*****************************************************************************
;  T_max, T_min, T_typ, L_max, L_min, and L_tpy scaled from F6 to F9.
;*****************************************************************************

T_min_TEB_F9=[[219.,216.,241.,242.,209.,214.,217.,217.],[0,0,0,373.,0,0,0,0]]
T_max_TEB_F9=[[431.,381.,740.,373.,400.,430.,436.,436.],[0,0,0,740.,0,0,0,0]]
T_typ_TEB_F9=[[243.,286.,416.,322.,310.,340.,340.,340.],[0,0,0,416.,0,0,0,0]]
L_min_TEB_F9=[[1.81,0.0169,7.99,0.0460,0.381,1.60,1.92,1.92],[0,0,0,7.99,0,0,0,0]]
L_max_TEB_F9=[[34.7,6.34,906.,7.99,39.4,38.5,32.6,32.6],[0,0,0,906.,0,0,0,0]]
L_typ_TEB_F9=[[3.46,0.214,21.4,1.77,11.5,16.5,14.5,14.5],[0,0,0,21.4,0,0,0,0]]

;*****************************************************************************
;  T_obc, Slope of T_obc, and Standard deviation of T_obc (SRV0598, SRV0654, and SRV0095).
;*****************************************************************************

!p.multi=[0,2,1]

title='T_obc vs Scan (SRV0598 and SRV0654)'

FOR ih=0, nham-1 DO BEGIN
	title1='HAM='+strtrim(string(ih+1),2)

	ymax=max(T_obc_2[*,ih,*])
	plot,T_obc_2[*,ih,0],xtit='Scan',ytit='T_obc',yrange=[ymax-0.05,ymax+0.05],title=title1, $
		charsize=1.2,charthick=5,/nodata

	FOR col=0, ncollects-1 DO BEGIN
		oplot,T_obc_2[*,ih,col],symsize=1,color=lcol[col],psym=symbol[col]
		oplot,D[*],Slope_temp_1[4,col,ih,0]+Slope_temp_1[4,col,ih,1]*D[*],color=lcol[col]

	ENDFOR
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='T_obc vs Collect (SRV0598 and SRV0654)'

FOR ih=0, nham-1 DO BEGIN
	title1='HAM='+strtrim(string(ih+1),2)+', Slope='+strtrim(string(Slope_temp_3[4,ih,1]),2)

	ymax=max(T_obc[ih,*])
	plot,T_obc[ih,*],xtit='Collect',ytit='T_obc',xrange=[0,ncollects],yrange=[ymax-0.05,ymax+0.05],title=title1, $
		charsize=1.2,charthick=5,/nodata
	oplot,T_obc[ih,*],symsize=1,color=lcol[0],psym=symbol[0]
	oplot,D[*],Slope_temp_3[4,ih,0]+Slope_temp_3[4,ih,1]*D[*],color=lcol[1]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='Standard Deviation of T_obc vs Collect (SRV0095)'

FOR ih=0, nham-1 DO BEGIN
	title1='HAM='+strtrim(string(ih+1),2)+', Std_avg='+strtrim(string(std_obc_temp1[ih]),2)

	ymax=max(std_obc_temp1[ih,*])
	plot,std_obc_temp1[ih,*],xtit='Collect',ytit='Standard Deviation of T_obc',xrange=[0,ncollects], $
		yrange=[0,ymax+0.04],title=title1,charsize=1.2,charthick=5,/nodata
	oplot,std_obc_temp1[ih,*],symsize=1,color=lcol[0],psym=symbol[0]
	oplot,std_obc_temp1[ih,*],color=lcol[0]
	oplot,[0,100],[0.03,0.03],color=lcol[1],linestyle=2,thick=1.5
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

;*****************************************************************************
;  Radiometric response characterization uncertainty (RRCU) (SRV0448).
;*****************************************************************************

!p.multi=[0,2,3]
title=strarr(6)

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	E=findgen(detectors_TEB[b])
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': RRCU vs Detector (SRV0448)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit with GC)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': RRCU vs Detector (SRV0448)'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit with GC)'
			ENDIF

			j=0
			FOR ifit=0, 2 DO BEGIN
				FOR cor=0, 1 DO BEGIN
					ymax=max(rrcu[b,ih,*,is,cor,ifit])
					IF ymax LT 1 THEN ymax=1.1

					plot,E[*],rrcu[b,ih,*,is,cor,ifit],xtit='Detectors',ytit='RRCU',yrange=[0,ymax], $
						title=title[j],charsize=1.2,charthick=5,/nodata

					oplot,E[*],rrcu[b,ih,*,is,cor,ifit],symsize=1,color=lcol[j],psym=symbol[j]
					oplot,E[*],rrcu[b,ih,*,is,cor,ifit],color=lcol[j]
					oplot,[0,100],[1,1],color=lcol[1],linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Radiometric response non-linearity (RRNL) (SRV0595).
;*****************************************************************************

!p.multi=[0,2,3]
title=strarr(6)

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	E=findgen(detectors_TEB[b])
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': RRNL vs Detector (SRV0595)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit with GC)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': RRNL vs Detector (SRV0595)'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit with GC)'
			ENDIF

			j=0
			FOR ifit=0, 2 DO BEGIN
				FOR cor=0, 1 DO BEGIN
					ymax=max(rrnl[b,ih,*,is,cor,ifit])
					IF ymax LT 1 THEN ymax=1.1

					plot,E[*],rrnl[b,ih,*,is,cor,ifit],xtit='Detectors',ytit='RRNL',yrange=[0,ymax], $
						title=title[j],charsize=1.2,charthick=5,/nodata

					oplot,E[*],rrnl[b,ih,*,is,cor,ifit],symsize=1,color=lcol[j],psym=symbol[j]
					oplot,E[*],rrnl[b,ih,*,is,cor,ifit],color=lcol[j]
					oplot,[0,100],[1,1],color=lcol[1],linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  NEdT at T_typ (SRV0053).
;*****************************************************************************

factor=(6./9.)^2
print,factor
NEdT_typ_req=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.multi=[0,2,2]
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': NEdT at T_typ (SRV0053)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (function powell)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted function powell)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (weighted cubic poly_fit)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': NEdT at T_typ (SRV0053)'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (function powell)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted function powell)'
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (weighted cubic poly_fit)'
			ENDIF

			j=0
			G=findgen(detectors_TEB[b])		
			FOR ifit=0, 1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,G[*],factor*NEdT_typ[b,ih,*,is,ifit2,ifit],xtit='Detectors',ytit='NEdT', $
						yrange=[0,NEdT_typ_req[b]+.1],xrange=[0,detectors_TEB[b]],title=title[j], $
						charsize=1.2,charthick=5,/nodata
					oplot,G[*],factor*NEdT_typ[b,ih,*,is,ifit2,ifit],symsize=1,color=lcol[j],psym=symbol[j]
					oplot,G[*],factor*NEdT_typ[b,ih,*,is,ifit2,ifit],color=lcol[j]
					oplot,[0,50],[NEdT_typ_req[b,0],NEdT_typ_req[b,0]],symsize=1,color=lcol[1], $
						linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Absolute Radiance Difference (SRV0545 and SRV0546).
;*****************************************************************************

FOR col=0, ncollects-1 DO BEGIN
	IF col GT 0 AND col LT ncollects-1 THEN BEGIN
		IF abs(T_bcs[col-1]-267) GT abs(T_bcs[col]-267) AND abs(T_bcs[col]-267) LT abs(T_bcs[col+1]-267) THEN BEGIN
			col_267=col
		ENDIF
		IF abs(T_bcs[col-1]-230) GT abs(T_bcs[col]-230) AND abs(T_bcs[col]-230) LT abs(T_bcs[col+1]-230) THEN BEGIN
			col_230=col
		ENDIF
		IF abs(T_bcs[col-1]-270) GT abs(T_bcs[col]-270) AND abs(T_bcs[col]-270) LT abs(T_bcs[col+1]-270) THEN BEGIN
			col_270=col
		ENDIF
		IF abs(T_bcs[col-1]-310) GT abs(T_bcs[col]-310) AND abs(T_bcs[col]-310) LT abs(T_bcs[col+1]-310) THEN BEGIN
			col_310=col
		ENDIF
	ENDIF
ENDFOR
col_190=0
col_340=ncollects-1
scol=[col_190,col_230,col_270,col_310,col_340]

ARD_req_I=[5,2.5]

G=findgen(detectors_TEB[0])
FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 0 THEN goto,skipi
	!p.multi=[0,2,3]
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2) $
				+': Absolute Radiance Difference, T_bcs=267 (SRV0546)'
			title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic ameoba)'
			title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic ameoba with GC)'
			title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic poly_fit)'
			title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic poly_fit with GC)'
			title[4]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (cubic poly_fit)'
			title[5]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (cubic poly_fit with GC)'

			j=0
			FOR ifit=0, 2 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,G[*],ARD[col_267,b,ih,*,is,ifit2,ifit],xtit='Detectors',ytit='ARD', $
						yrange=[-ARD_req_I[b]-1,ARD_req_I[b]+1],xrange=[0,detectors_TEB[b]], $
						title=title[j],charsize=1.2,charthick=5,/nodata
					oplot,G[*],ARD[col_267,b,ih,*,is,ifit2,ifit],symsize=1,color=lcol[j],psym=symbol[j]
					oplot,G[*],ARD[col_267,b,ih,*,is,ifit2,ifit],color=lcol[j]
					oplot,[0,50],[ARD_req_I[b],ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
					oplot,[0,50],[-ARD_req_I[b],-ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
					j=j+1
				ENDFOR
				XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDFOR
	ENDFOR
	skipi:
ENDFOR

ARD_req_M=[[0,0,12.3,2.1,1.6,1.6],[7.0,5.7,2.4,0.60,.60,.60],[0.7,0.7,0.6,0.4,0.4,0.4], $
	[0.7,0.7,0.4,0.4,0.4,0.4],[0.7,0.7,0.5,0.4,0.4,0.4]]
collect_name=['190','230','270','310','340']

FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 1 THEN goto,skipm

	G=findgen(detectors_TEB[b])
	title2=band_name_TEB[b]+': Absolute Radiance Difference (SRV0545)'
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			!p.multi=[0,3,2]
			!p.position=0
			FOR j=0, 4 DO BEGIN
				title1=band_name_TEB[b]+': Absolute Radiance Difference, T='+collect_name[j]+' (SRV0545)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit with GC)'

				k=0
				FOR ifit=0, 2 DO BEGIN
					FOR ifit2=0, 1 DO BEGIN
						ymax=max(ARD[scol[j],b,ih,*,is,ifit2,ifit],min=ymin)

						plot,G[*],ARD[scol[j],b,ih,*,is,ifit2,ifit],xtit='Detectors', $
							ytit='ARD',yrange=[ymin,ymax],xrange=[0,detectors_TEB[b]], $
							title=title[k],charsize=1.2,charthick=5,/nodata
						oplot,G[*],ARD[scol[j],b,ih,*,is,ifit2,ifit],symsize=1, $
							color=lcol[k],psym=symbol[k]
						oplot,G[*],ARD[scol[j],b,ih,*,is,ifit2,ifit],color=lcol[k]
						oplot,[0,50],[ARD_req_M[b-2,j],ARD_req_M[b-2,j]],symsize=1,color=lcol[1], $
							linestyle=2,thick=1.5
						oplot,[0,50],[-ARD_req_M[b-2,j],-ARD_req_M[b-2,j]],symsize=1,color=lcol[1], $
							linestyle=2,thick=1.5
						k=k+1
					ENDFOR
				ENDFOR
				XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDFOR
	ENDFOR
	skipm:
ENDFOR

FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 0 THEN goto,skipi_obc
	!p.multi=[0,2,3]
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2) $
				+': Absolute Radiance Difference of the OBC, T_bcs=267 (SRV0546)'
			title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic ameoba)'
			title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic ameoba with GC)'
			title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic poly_fit)'
			title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (quadratic poly_fit with GC)'
			title[4]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (cubic poly_fit)'
			title[5]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
				+' (cubic poly_fit with GC)'

			j=0
			FOR ifit=0, 2 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					plot,G[*],ARD_obc[col_267,b,ih,*,is,ifit2,ifit],xtit='Detectors',ytit='ARD_obc', $
						yrange=[-ARD_req_I[b]-1,ARD_req_I[b]+1],xrange=[0,detectors_TEB[b]], $
						title=title[j],charsize=1.2,charthick=5,/nodata
					oplot,G[*],ARD_obc[col_267,b,ih,*,is,ifit2,ifit],symsize=1,color=lcol[j],psym=symbol[j]
					oplot,G[*],ARD_obc[col_267,b,ih,*,is,ifit2,ifit],color=lcol[j]
					oplot,[0,50],[ARD_req_I[b],ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
					oplot,[0,50],[-ARD_req_I[b],-ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
					j=j+1
				ENDFOR
				XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDFOR
	ENDFOR
	skipi_obc:
ENDFOR

ARD_req_M=[[0,0,12.3,2.1,1.6,1.6],[7.0,5.7,2.4,0.60,.60,.60],[0.7,0.7,0.6,0.4,0.4,0.4], $
	[0.7,0.7,0.4,0.4,0.4,0.4],[0.7,0.7,0.5,0.4,0.4,0.4]]
collect_name=['190','230','270','310','340']

FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 1 THEN goto,skipm_obc

	G=findgen(detectors_TEB[b])
	title2=band_name_TEB[b]+': Absolute Radiance Difference (SRV0545)'
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			!p.multi=[0,3,2]
			!p.position=0
			FOR j=0, 4 DO BEGIN
				title1=band_name_TEB[b]+': Absolute Radiance Difference of the OBC, T=' $
					+collect_name[j]+' (SRV0545)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit with GC)'

				k=0
				FOR ifit=0, 2 DO BEGIN
					FOR ifit2=0, 1 DO BEGIN
						ymax=max(ARD_obc[scol[j],b,ih,*,is,ifit2,ifit],min=ymin)

						plot,G[*],ARD_obc[scol[j],b,ih,*,is,ifit2,ifit],xtit='Detectors', $
							ytit='ARD_obc',yrange=[ymin,ymax],xrange=[0,detectors_TEB[b]], $
							title=title[k],charsize=1.2,charthick=5,/nodata
						oplot,G[*],ARD_obc[scol[j],b,ih,*,is,ifit2,ifit],symsize=1, $
							color=lcol[k],psym=symbol[k]
						oplot,G[*],ARD_obc[scol[j],b,ih,*,is,ifit2,ifit],color=lcol[k]
						oplot,[0,50],[ARD_req_M[b-2,j],ARD_req_M[b-2,j]],symsize=1,color=lcol[1], $
							linestyle=2,thick=1.5
						oplot,[0,50],[-ARD_req_M[b-2,j],-ARD_req_M[b-2,j]],symsize=1,color=lcol[1], $
							linestyle=2,thick=1.5
						k=k+1
					ENDFOR
				ENDFOR
				XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
			ENDFOR
		ENDFOR
	ENDFOR
	skipm_obc:
ENDFOR

;*****************************************************************************
;  RRU (SRV0613).
;*****************************************************************************

RRU_req=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]
H=findgen(ncollects)

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.multi=[0,2,3]
	!p.position=0

	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			IF band_type_TEB[b] EQ 0 THEN BEGIN
				title1=band_name_TEB[b]+': RRU (SRV0613)'
				title[0]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)+' (cubic poly_fit with GC)'
			ENDIF
			IF band_type_TEB[b] EQ 1 THEN BEGIN
				title1=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+': RRU (SRV0613)'
				title[0]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba)'
				title[1]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic ameoba with GC)'
				title[2]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit)'
				title[3]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (quadratic poly_fit with GC)'
				title[4]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit)'
				title[5]=band_name_TEB[b]+' SS'+strtrim(string(is+1),2)+', '+'HAM='+strtrim(string(ih+1),2) $
					+' (cubic poly_fit with GC)'
			ENDIF

			j=0
			G=findgen(detectors_TEB[b])	
			FOR ifit=0, 2 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					ymax=max(RRU[*,b,ih,is,ifit2,ifit])
					plot,H[*],RRU[0,b,ih,*,is,0,0],xtit='Collects',ytit='RRU',yrange=[0,ymax], $
						xrange=[0,ncollects],title=title[j],charsize=1.2,charthick=5,/nodata
					oplot,H[*],RRU[*,b,ih,is,ifit2,ifit],symsize=1,color=lcol[j],psym=symbol[j]
					oplot,H[*],RRU[*,b,ih,is,ifit2,ifit],color=lcol[j]
					oplot,[0,1000],[Planck_deriv(0.1*T_min_TEB[b,0],lambda_TEB[b]), $
						Planck_deriv(0.1*T_min_TEB[b,0],lambda_TEB[b])],symsize=1, $
						color=lcol[1],linestyle=2,thick=1.5
					oplot,[0,1000],[Planck_deriv(0.9*T_max_TEB[b,0],lambda_TEB[b]), $
						Planck_deriv(0.9*T_max_TEB[b,0],lambda_TEB[b])],symsize=1, $
						color=lcol[1],linestyle=2,thick=1.5
					j=j+1
				ENDFOR
			ENDFOR
			XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
		ENDFOR
	ENDFOR
ENDFOR
print,T_bcs
skip_loop:

END
