;*****************************************************************************
;  Function which returns the number of collects in a given directory.
;
;  Inputs:
;  1) directory -- directory containing dump files.
;
;  Outputs:
;  1) ncollect -- number of collects.
;  1) type -- band range under consideration (RSB, TEB, ...).
;  
;  v1 - 4/14/2008 - Jeff McIntire
;*****************************************************************************

PRO n_collect, directory, ncollect,type

; Get list of .dmp files from specified path. 
spawn,'ls -C1 '+directory+'*.dmp',list_files
nfile=N_ELEMENTS(list_files)
IF nfile EQ 0 THEN BEGIN
	ncollect=0
	goto,skipout
ENDIF

count1=0
count2=0
count3=0
count4=0
FOR ifile=0, nfile-1 DO BEGIN

	; Pick out EV files.
	b1=strsplit(list_files[ifile],'/',/Extract)
	b2=N_ELEMENTS(b1)
	b3=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+10,2)
	IF b3 NE 'EV' THEN goto,skip

	; Count the numbers of M1, M12, and M14 files.
	b4=strmid(b1[b2-1],strpos(b1[b2-1],'/',/Reverse_Search)+18,3)
	IF b4 EQ 'M1.' THEN count1=count1+1
	IF b4 EQ 'M11' THEN count2=count2+1
	IF b4 EQ 'M12' THEN count3=count3+1
	IF b4 EQ 'M14' THEN count4=count4+1

	skip:
ENDFOR

; Determine the number of collects.
IF count1 GT 0 THEN BEGIN
	ncollect=count1
	IF count2 EQ 0 THEN type='VisNIR'
	goto,skip_VisNIR
ENDIF
IF count2 GT 0 THEN BEGIN
	ncollect=count2
	type='RSB'
	goto,skip_RSB
ENDIF
IF count3 GT 0 THEN BEGIN
	ncollect=count3
	IF count2 EQ 0 THEN BEGIN
		type='TEB'
		goto,skip_TEB
	ENDIF
	type='SMWIR'
	goto,skip_SMWIR
ENDIF
IF count4 GT 0 THEN BEGIN
	ncollect=count4
	type='LWIR'
ENDIF
skip_VisNIR:
skip_RSB:
skip_TEB:
skip_SMWIR:

skipout:

END
