;*****************************************************************************
;  Function which returns the initial HAM side for all collects in a directory.
;
;  Inputs:
;  1) directory -- directory containing dump files.
;
;  Outputs:
;  1) ham -- array of initial HAM sides for a set of collects.
;  
;  v1 - 4/14/2008 - Jeff McIntire
;*****************************************************************************

FUNCTION initial_ham_side, directory

z1=[0,3,5,7,4,76,8,4]
z=stddev(z1)

n_collect,directory,ncollect,type

; Get list of .dmp files from specified path. 
spawn,'ls -C1 '+directory+'*.dmp',list_files
nfile=N_ELEMENTS(list_files)
IF nfile EQ 0 THEN RETURN,0

IF type EQ 'VisNIR' THEN nb=9
IF type EQ 'RSB' THEN nb=14
IF type EQ 'SMWIR' THEN nb=8
IF type EQ 'TEB' THEN nb=8
IF type EQ 'LWIR' THEN nb=5

; Number of types (EV, SV, OBC, and SD)
n=nfile/(nb*ncollect)

; Loop over the first band in each collect.
count1=0
ham=intarr(ncollect)
FOR ifile=0, nfile-1, n*nb DO BEGIN

	; Read in the first HAM side per collect.
	ab=''
	openr,lun,list_files[ifile],/Get_Lun
	readf,lun,ab
	a1=strsplit(ab,String(9B),/Extract)
	ham(count1)=a1(3)
	count1=count1+1
	Free_Lun,lun

	skip:
ENDFOR

RETURN,ham

END
