;*****************************************************************************
;  Batch file which creates a .sav file containing various general parameters
;  associated with NPP data.
;
;  Output:
;  1) general.VisNIR.sav
;  2) general.SMWIR.sav
;  3) general.LWIR.sav
;  4) general.RSB.sav
;  5) general.TEB.sav
;  
;  v1 - 12/21/2007 - Jeff McIntire
;*****************************************************************************

PRO general_data

nham=2
maxgain=2
maxsubsets=2
maxdet=32

; DNB bands.
nbands_BND=4

; VisNIR bands.
nbands_VisNIR=9
band_name_VisNIR=['I1','I2','M1','M2','M3','M4','M5','M6','M7']
band_type_VisNIR=[1,1,0,0,0,0,0,0,0]					; I bands = 1 and M bands = 0.
gain_type_VisNIR=[0,0,1,1,1,1,1,0,1]					; Single gain = 0 and dual gain = 1.
detectors_VisNIR=[32,32,16,16,16,16,16,16,16]
subsets_VisNIR=[2,2,1,1,1,1,1,1,1]					; Number of subsets.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands_VisNIR,band_name_VisNIR,band_type_VisNIR,gain_type_VisNIR, $
	detectors_VisNIR,subsets_VisNIR,filename='/home/jmcintire/VIIRS_Data/general.VisNIR.sav'

; SMWIR bands.
nbands_SMWIR=8
band_name_SMWIR=['I3','I4','M10','M11','M12','M13','M8','M9']
band_type_SMWIR=[1,1,0,0,0,0,0,0]					; I bands = 1 and M bands = 0.
gain_type_SMWIR=[0,0,0,0,0,1,0,0]					; Single gain = 0 and dual gain = 1.
detectors_SMWIR=[32,32,16,16,16,16,16,16]
subsets_SMWIR=[2,2,1,1,1,1,1,1]						; Number of subsets.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands_SMWIR,band_name_SMWIR,band_type_SMWIR,gain_type_SMWIR, $
	detectors_SMWIR,subsets_SMWIR,filename='/home/jmcintire/VIIRS_Data/general.SMWIR.sav'

; LWIR bands.
nbands_LWIR=5
band_name_LWIR=['I5','M14','M15','M16A','M16B']
band_type_LWIR=[1,0,0,0,0]						; I bands = 1 and M bands = 0.
gain_type_LWIR=[0,0,0,0,0]						; Single gain = 0 and dual gain = 1.
detectors_LWIR=[32,16,16,16,16]
subsets_LWIR=[2,1,1,1,1]						; Number of subsets.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands_LWIR,band_name_LWIR,band_type_LWIR,gain_type_LWIR, $
	detectors_LWIR,subsets_LWIR,filename='/home/jmcintire/VIIRS_Data/general.LWIR.sav'

; RSB bands.
nbands_RSB=14
band_name_RSB=['I1','I2','I3','M1','M2','M3','M4','M5','M6','M7','M8','M9','M10','M11']
band_type_RSB=[1,1,1,0,0,0,0,0,0,0,0,0,0,0]				; I bands = 1 and M bands = 0.
gain_type_RSB=[0,0,0,1,1,1,1,1,0,1,0,0,0,0]				; Single gain = 0 and dual gain = 1.
detectors_RSB=[32,32,32,16,16,16,16,16,16,16,16,16,16,16]
subsets_RSB=[2,2,2,1,1,1,1,1,1,1,1,1,1,1]				; Number of subsets.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands_RSB,band_name_RSB,band_type_RSB,gain_type_RSB, $
	detectors_RSB,subsets_RSB,filename='/home/jmcintire/VIIRS_Data/general.RSB.sav'

; TEB bands.
nbands_TEB=8
band_name_TEB=['I4','I5','M12','M13','M14','M15','M16A','M16B']
band_type_TEB=[1,1,0,0,0,0,0,0]						; I bands = 1 and M bands = 0.
gain_type_TEB=[0,0,0,1,0,0,0,0]						; Single gain = 0 and dual gain = 1.
detectors_TEB=[32,32,16,16,16,16,16,16]
subsets_TEB=[2,2,1,1,1,1,1,1]						; Number of subsets.
L_max_TEB=[[3.01,15.41,2.82,3.47,17.54,17.08,14.48,14.48],[0,0,0,404.33,0,0,0,0]]
L_min_TEB=[[0.00180,0.813,0.00780,0.0214,0.371,0.726,0.873,0.873],[0,0,0,3.47,0,0,0,0]]
L_typ_TEB=[[0.11,1.53,0.1,0.79,5.14,9.7,8.97,8.97],[0,0,0,9.53,0,0,0,0]]
T_max_TEB=[[353.,340.,353.,343.,336.,343.,340.,340.],[0,0,0,634.,0,0,0,0]]
T_min_TEB=[[210.,190.,230.,230.,190.,190.,190.,190.],[0,0,0,343.,0,0,0,0]]
T_typ_TEB=[[270.,210.,270.,300.,270.,300.,300.,300.],[0,0,0,380.,0,0,0,0]]
lambda_TEB=[3.740,11.450,3.700,4.050,8.550,10.763,12.013,12.013]	; Center wavelengths.

save,/compress,nham,maxsubsets,maxdet,maxgain,nbands_TEB,band_name_TEB,band_type_TEB,gain_type_TEB, $
	detectors_TEB,subsets_TEB,L_max_TEB,L_min_TEB,L_typ_TEB,T_max_TEB,T_min_TEB,T_typ_TEB,lambda_TEB, $
	filename='/home/jmcintire/VIIRS_Data/general.TEB.sav'

END
